@@ -1,4 +1,4 @@
-# Copyright (c) 2012-2014 Trevor L. Davis <trevor.l.davis@stanford.edu>  
+# Copyright (c) 2012-2017 Trevor L. Davis <trevor.l.davis@stanford.edu>  
 #  
 #  This file is free software: you may copy, redistribute and/or modify it  
 #  under the terms of the GNU General Public License as published by the  
@@ -92,7 +92,7 @@ ArgumentParser <- function(...,
                     if (interactive()) {
                         # cat(output, sep="\n")
                         # stop("help requested") 
-                        stop(paste("help requested", paste(output, collapse="\n")), sep="\n")
+                        stop(paste("help requested:\n", paste(output, collapse="\n")), sep="\n")
                     } else {
                         cat(output, sep="\n")
                         quit(status=0)
@@ -110,13 +110,23 @@ ArgumentParser <- function(...,
                 if (interactive()) { 
                     # cat(output, file=stderr(), sep="\n")
                     # stop("python error")
-                    stop(paste("python error", paste(output, collapse="\n")), sep="\n")
+                    stop(paste("python error:\n", paste(output, collapse="\n")), sep="\n")
                 } else {
                     cat(output, file=stderr(), sep="\n")
                     quit(status=1)
                 }
             } else {
-                return(rjson::fromJSON(paste(output, collapse="")))
+                args <- rjson::fromJSON(paste(output, collapse=""))
+                if(is.list(args)) {
+                    return(args)
+                } else { # Version number request
+                    if (interactive() ) {
+                        stop(paste("version requested:", output), sep="\n")
+                    } else {
+                        cat(output, sep="\n")
+                        quit(status=0)
+                    }
+                }
             }
         }
         print_help <- function(.) {
@@ -192,6 +202,12 @@ convert_..._to_arguments <- function(mode, ...) {
         choices <- convert_argument(argument_list[[ii]])
         proposed_arguments[ii] <- sprintf("choices=%s", choices)
     }
+    # Fix bug reported by Claire D McWhite
+    if(mode == "add_argument" && any(grepl("required=", proposed_arguments))) {
+        ii <- grep("required=", proposed_arguments)
+        required <- convert_argument(argument_list[[ii]])
+        proposed_arguments[ii] <- sprintf("required=%s", required)
+    }
     # Feature request from Paul Newell
     if(mode == "add_argument" && any(grepl("metavar=", proposed_arguments))) {
         ii <- grep("metavar=", proposed_arguments)
